syntax_sugar library
Extensions
-
AllToString
on Iterable<
T> - MatchIndexOf on String
- MatchOneOf on String
- RegexpMatchChain on String
-
Chain style programming syntax sugar for regular expressions on strings.
This extension directly mapped the RegExp interface in the
dart:core. - RegexpMatchOneOf on Set
Functions
-
nullableMax<
T extends num> (T? a, T? b) → T? -
nullableMin<
T extends num> (T? a, T? b) → T? -
satisfyAll(
Iterable< bool> conditions) → bool - Satisfy all of the conditions, and it wll return true.
-
satisfyAny(
Iterable< bool> conditions) → bool - Satisfy any of the conditions, and it wll return true.